income_tax_model_func: YSI Applied Income Tax Rates Function for modeling new rates...

View source: R/ysi_income_tax.R

income_tax_model_funcR Documentation

YSI Applied Income Tax Rates Function for modeling new rates and/or thresholds

Description

Can be used on taxable income (TaxableInc) or another income source that uses marginal income tax rates.

Usage

income_tax_model_func(df = Null, Model_name = NULL)

Arguments

Model_name

The the model name .

income

A numeric vector of income ($)

Value

A vector


youngstreetinitiative/ysi documentation built on April 11, 2024, 2:32 a.m.