income_tax_rates_func: YSI Applied Income Tax Rates Function

View source: R/ysi_income_tax.R

income_tax_rates_funcR Documentation

YSI Applied Income Tax Rates Function

Description

Can be used on taxable income (TaxableInc) or another income source that uses marginal income tax rates. Previously called RegIncTAXfn()

Usage

income_tax_rates_func(income = NULL, year = NULL)

Arguments

income

A numeric vector of income ($)

year

The finanical year of interest, in the form "2013-14", as a vector.

Details

To model a new set of rates and thresholds use income_tax_model_func()

Value

A vector


youngstreetinitiative/ysi documentation built on April 11, 2024, 2:32 a.m.