ysi_income_tax: YSI Income Tax Assesment Function

View source: R/ysi_income_tax.R

ysi_income_taxR Documentation

YSI Income Tax Assesment Function

Description

This function combines all the nessesary income tax functions and data set mutations to be an all-in-one function for calculating Income Tax

Usage

ysi_income_tax(df = NULL)

Arguments

df

Argument is intended to be a survey with the Tax_Matrix set, as a data frame

Value

A data frame


youngstreetinitiative/ysi documentation built on April 11, 2024, 2:32 a.m.