ysi_init: YSI Startup Function

View source: R/ysi_init.R

ysi_initR Documentation

YSI Startup Function

Description

This function is for the star of your script, bringing in the data and setting the data up for your analysis. There is no need to be concerned that your varible needs are not in every wave, as this function will just find whatever is avilable.

Usage

ysi_init(set = "key", xwave = F, wave_n = 14)

Arguments

set

This argument needs to be a string that is one of the set names in the YSI master sheet.

xwave

Expects a logical input, xwave data (T) or single wave data (F)

wave_n

If you want a single wave of data, specify which year in the form of an integer between 1 and 14

Value

A set of tables, including Master (the variable master sheet) and your_data (your data subset), and user_subset (filtered version of Master with your set's variables)


youngstreetinitiative/ysi documentation built on April 11, 2024, 2:32 a.m.