ysi_mutate_combine: ysi Mutate_combine Function

View source: R/mutate_variables.R

ysi_mutate_combineR Documentation

ysi Mutate_combine Function

Description

This function mutates multiple useful and commonly used variables for YSI analysis.

Usage

ysi_mutate_combine(df = NULL)

Arguments

df

Argument is intended to be a data frame

Details

It generates the following, which are mostly a sum of the posative and negative HILDA variables:

House Income (HouseInc) Total Individual Income (TotalIncome) Regular Individual Income (RegInc) HouseHold level combined Assets (Assets) Idividual Net Rent (NetRent)

Value

A data frame


youngstreetinitiative/ysi documentation built on April 11, 2024, 2:32 a.m.