ysi_super_tax: YSI Super Tax Assesment Function (Working...)

View source: R/ysi_super_tax.R

ysi_super_taxR Documentation

YSI Super Tax Assesment Function (Working...)

Description

This function combines all the nessesary Superannuation tax functions and data set mutations to be an all-in-one function for calculating Super Tax (Grace to fill in soon) (Requires Tax_Matrix set) (Currently only usable in Wave14)

Usage

ysi_super_tax(df = NULL)

Arguments

df

Argument is intended to be a survey with the Tax_Matrix set, as a data frame

Value

A data frame


youngstreetinitiative/ysi documentation built on April 11, 2024, 2:32 a.m.