View source: R/ysi_income_tax.R
| income_tax_rates_func | R Documentation |
Can be used on taxable income (TaxableInc) or another income source that uses marginal income tax rates. Previously called RegIncTAXfn()
income_tax_rates_func(income = NULL, year = NULL)
income |
A numeric vector of income ($) |
year |
The finanical year of interest, in the form "2013-14", as a vector. |
To model a new set of rates and thresholds use income_tax_model_func()
A vector
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.