View source: R/ysi_income_tax.R
| ysi_income_tax | R Documentation |
This function combines all the nessesary income tax functions and data set mutations to be an all-in-one function for calculating Income Tax
ysi_income_tax(df = NULL)
df |
Argument is intended to be a survey with the Tax_Matrix set, as a data frame |
A data frame
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.