View source: R/mutate_variables.R
| ysi_mutate_combine | R Documentation |
This function mutates multiple useful and commonly used variables for YSI analysis.
ysi_mutate_combine(df = NULL)
df |
Argument is intended to be a data frame |
It generates the following, which are mostly a sum of the posative and negative HILDA variables:
House Income (HouseInc) Total Individual Income (TotalIncome) Regular Individual Income (RegInc) HouseHold level combined Assets (Assets) Idividual Net Rent (NetRent)
A data frame
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.